@@ -15,4 +15,16 @@ test_that("margins intersect", {
   expect_that(margins(vars, c("c", "f"))[-1], 
     equals(list("c", "f", c("c", "f"))))
   
+})
+
+test_that("(all) comes after NA", {
+  df <- data.frame(a = c("a", "b", NA), value = 1)
+
+  df2 <- add_margins(df, "a")
+  expect_that(levels(df2$a), equals(c("a", "b", NA, "(all)")))
+  
+  dc <- dcast(df, a ~ ., margins = TRUE, fun = length)
+  expect_that(levels(dc$a), equals(c("a", "b", NA, "(all)")))
+  expect_that(as.character(dc$a), equals(c("a", "b", NA, "(all)")))
+
 })
\ No newline at end of file
